window.Gleam.initSearch([{"doc":"processgroups","title":"processgroups","content":"# process groups for gleam\r\n\r\nSimple wrapper around [erlang process groups] in gleam.\r\n\r\nThis library mainly wraps [erlang process groups], so go to its documentation for details.\r\n\r\n[![Package Version](https://img.shields.io/hexpm/v/processgroups)](https://hex.pm/packages/processgroups)\r\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/processgroups/)\r\n\r\n## Usage\r\n\r\nAdd this  library to your Gleam project\r\n\r\n```sh\r\ngleam add processgroups\r\n```\r\n\r\nAnd use it in your project\r\n\r\n```gleam\r\nimport io\r\nimport processgroups as pg\r\nimport gleam/erlang/process\r\n\r\n// some type we use to distinguish process groups\r\n// could also be strings\r\ntype ProcessGroups {\r\n    ExampleProcessGroup\r\n}\r\n\r\npub fn main() {\r\n    // start process groups\r\n    pg.start_link()\r\n\r\n    // put ourself into a process group\r\n    pg.join(ExampleProcessGroup, process.self())\r\n\r\n    // list processes in the group\r\n    io.debug(pg.get_members(ExampleProcessGroup))\r\n    // output: [&lt;our-process-id&gt;]\r\n\r\n    // leave the group\r\n    pg.leave(ExampleProcessGroup, process.self())\r\n\r\n    // list processes in the group\r\n    io.debug(pg.get_members(ExampleProcessGroup))\r\n    // output: []\r\n\r\n    // monitor a process group\r\n    let #(group_monitor, current_processes) = pg.monitor(ExampleProcessGroup)\r\n    io.debug(current_processes)\r\n    // output: []\r\n    \r\n    // join to create monitoring event\r\n    pg.join(ExampleProcessGroup, process.self())\r\n\r\n    // get the created event\r\n    let assert Ok(pg.ProcessJoined(ExampleProcessGroup, new_pids)) = pg.selecting_process_group_monitor(\r\n      process.new_selector(),\r\n      group_monitor,\r\n      fn(pid) {pid}\r\n    ) |&gt; process.select(100)\r\n}\r\n```\r\n\r\n\r\nFurther documentation can be found at &lt;https://hexdocs.pm/processgroups&gt;.\r\n\r\n## Development\r\n\r\n```sh\r\ngleam run   # Run the project\r\ngleam test  # Run the tests\r\ngleam shell # Run an Erlang shell\r\n```\r\n\r\n[erlang process groups]: https://www.erlang.org/doc/man/pg.html\r\n","url":"index.html"},{"doc":"processgroups","title":"GroupMonitor","content":"pub opaque type GroupMonitor(group)\n For monitoring, we use the `gleam/erlang/process`\n module and their way of handling messages.\n The GroupMonitor type is constructed when monitoring\n a process group. You can than use `selecting_process_group_monitor`\n To receive `GroupMonitorEvent` messages using `gleam/erlang/process.select`.\n\nSynonyms:\nprocessgroups.GroupMonitor\nprocessgroups GroupMonitor","url":"processgroups.html#GroupMonitor"},{"doc":"processgroups","title":"GroupMonitorEvent","content":"pub type GroupMonitorEvent(group) {\n  ProcessJoined(group: group, pids: List(process.Pid))\n  ProcessLeft(group: group, pids: List(process.Pid))\n}\n The events send when monitoring a process group.\nProcessJoined(group: group, pids: List(process.Pid))\n Some processes have joined\n\nProcessLeft(group: group, pids: List(process.Pid))\n Same process have left\n\nSynonyms:\nprocessgroups.GroupMonitorEvent\nprocessgroups GroupMonitorEvent","url":"processgroups.html#GroupMonitorEvent"},{"doc":"processgroups","title":"Scope","content":"pub type Scope =\n  atom.Atom\n A scope for process groups is an atom, we type alias to make it clearer\n\nSynonyms:\nprocessgroups.Scope\nprocessgroups Scope","url":"processgroups.html#Scope"},{"doc":"processgroups","title":"demonitor","content":"pub fn demonitor(group: a) -&gt; Bool\n\nSynonyms:\nprocessgroups.demonitor\nprocessgroups demonitor","url":"processgroups.html#demonitor"},{"doc":"processgroups","title":"demonitor_scope","content":"pub fn demonitor_scope(scope: Atom, group: a) -&gt; Bool\n\nSynonyms:\nprocessgroups.demonitor_scope\nprocessgroups demonitor_scope","url":"processgroups.html#demonitor_scope"},{"doc":"processgroups","title":"erlang_monitor_scope","content":"pub fn erlang_monitor_scope(\n  scope: Atom,\n  group: a,\n) -&gt; #(Reference, List(Pid))\n\nSynonyms:\nprocessgroups.erlang_monitor_scope\nprocessgroups erlang_monitor_scope","url":"processgroups.html#erlang_monitor_scope"},{"doc":"processgroups","title":"get_local_members","content":"pub fn get_local_members(group: a) -&gt; List(Pid)\n\nSynonyms:\nprocessgroups.get_local_members\nprocessgroups get_local_members","url":"processgroups.html#get_local_members"},{"doc":"processgroups","title":"get_local_members_scope","content":"pub fn get_local_members_scope(\n  scope: Atom,\n  group: a,\n) -&gt; List(Pid)\n\nSynonyms:\nprocessgroups.get_local_members_scope\nprocessgroups get_local_members_scope","url":"processgroups.html#get_local_members_scope"},{"doc":"processgroups","title":"get_members","content":"pub fn get_members(group: a) -&gt; List(Pid)\n\nSynonyms:\nprocessgroups.get_members\nprocessgroups get_members","url":"processgroups.html#get_members"},{"doc":"processgroups","title":"get_members_scope","content":"pub fn get_members_scope(scope: Atom, group: a) -&gt; List(Pid)\n\nSynonyms:\nprocessgroups.get_members_scope\nprocessgroups get_members_scope","url":"processgroups.html#get_members_scope"},{"doc":"processgroups","title":"join","content":"pub fn join(group: a, pid: Pid) -&gt; Nil\n\nSynonyms:\nprocessgroups.join\nprocessgroups join","url":"processgroups.html#join"},{"doc":"processgroups","title":"join_many","content":"pub fn join_many(group: a, pids: List(Pid)) -&gt; Nil\n\nSynonyms:\nprocessgroups.join_many\nprocessgroups join_many","url":"processgroups.html#join_many"},{"doc":"processgroups","title":"join_scope","content":"pub fn join_scope(scope: Atom, group: a, pid: Pid) -&gt; Nil\n\nSynonyms:\nprocessgroups.join_scope\nprocessgroups join_scope","url":"processgroups.html#join_scope"},{"doc":"processgroups","title":"join_scope_many","content":"pub fn join_scope_many(\n  scope: Atom,\n  group: a,\n  pids: List(Pid),\n) -&gt; Nil\n\nSynonyms:\nprocessgroups.join_scope_many\nprocessgroups join_scope_many","url":"processgroups.html#join_scope_many"},{"doc":"processgroups","title":"leave","content":"pub fn leave(group: a, pid: Pid) -&gt; Nil\n\nSynonyms:\nprocessgroups.leave\nprocessgroups leave","url":"processgroups.html#leave"},{"doc":"processgroups","title":"leave_many","content":"pub fn leave_many(group: a, pids: List(Pid)) -&gt; Nil\n\nSynonyms:\nprocessgroups.leave_many\nprocessgroups leave_many","url":"processgroups.html#leave_many"},{"doc":"processgroups","title":"leave_many_scope","content":"pub fn leave_many_scope(\n  scope: Atom,\n  group: a,\n  pids: List(Pid),\n) -&gt; Atom\n\nSynonyms:\nprocessgroups.leave_many_scope\nprocessgroups leave_many_scope","url":"processgroups.html#leave_many_scope"},{"doc":"processgroups","title":"leave_scope","content":"pub fn leave_scope(scope: Atom, group: a, pid: Pid) -&gt; Atom\n\nSynonyms:\nprocessgroups.leave_scope\nprocessgroups leave_scope","url":"processgroups.html#leave_scope"},{"doc":"processgroups","title":"monitor","content":"pub fn monitor(group: a) -&gt; #(GroupMonitor(a), List(Pid))\n\nSynonyms:\nprocessgroups.monitor\nprocessgroups monitor","url":"processgroups.html#monitor"},{"doc":"processgroups","title":"monitor_scope","content":"pub fn monitor_scope(\n  scope: Atom,\n  group: a,\n) -&gt; #(GroupMonitor(a), List(Pid))\n\nSynonyms:\nprocessgroups.monitor_scope\nprocessgroups monitor_scope","url":"processgroups.html#monitor_scope"},{"doc":"processgroups","title":"selecting_process_group_monitor","content":"pub fn selecting_process_group_monitor(\n  selector: Selector(a),\n  monitor: GroupMonitor(b),\n  mapping: fn(GroupMonitorEvent(b)) -&gt; a,\n) -&gt; Selector(a)\n Receive monitoring events.\n\n # Example\n\n \n import pg_for_gleam as pg\n import gelam/erlang/process\n\n let monitor = pg.monitor(SomeProcessGroup)\n\n let selector = pg.selecting_process_group_monitor(\n   selector: new_selector(),\n   monitor: monitor,\n   mapping: fn(gme) {gme}\n )\n\n case select(selector) {\n   Ok(ProcessJoined(_, pids)) -&gt; io.print(&quot;some process joined&quot;)\n   Ok(ProcessLeft(_, pids)) -&gt; io.print(&quot;some process left&quot;)\n   _ -&gt; panic\n }\n \nSynonyms:\nprocessgroups.selecting_process_group_monitor\nprocessgroups selecting_process_group_monitor","url":"processgroups.html#selecting_process_group_monitor"},{"doc":"processgroups","title":"start","content":"pub fn start(scope: Atom) -&gt; Result(Pid, Dynamic)\n\nSynonyms:\nprocessgroups.start\nprocessgroups start","url":"processgroups.html#start"},{"doc":"processgroups","title":"start_link","content":"pub fn start_link() -&gt; Result(Pid, Dynamic)\n\nSynonyms:\nprocessgroups.start_link\nprocessgroups start_link","url":"processgroups.html#start_link"},{"doc":"processgroups","title":"start_link_with_scope","content":"pub fn start_link_with_scope(scope: Atom) -&gt; Result(Pid, Dynamic)\n\nSynonyms:\nprocessgroups.start_link_with_scope\nprocessgroups start_link_with_scope","url":"processgroups.html#start_link_with_scope"},{"doc":"processgroups","title":"which_groups","content":"pub fn which_groups() -&gt; List(a)\n\nSynonyms:\nprocessgroups.which_groups\nprocessgroups which_groups","url":"processgroups.html#which_groups"},{"doc":"processgroups","title":"which_groups_scope","content":"pub fn which_groups_scope(scope: Atom) -&gt; List(a)\n\nSynonyms:\nprocessgroups.which_groups_scope\nprocessgroups which_groups_scope","url":"processgroups.html#which_groups_scope"},{"doc":"processgroups","title":"processgroups","content":"","url":"processgroups.html"}]);